@@ -1,5 +1,5 @@
 from abc import abstractmethod
-from typing import Type, TYPE_CHECKING, Any, List, TypeVar, cast, Callable, Literal
+from typing import Type, TYPE_CHECKING, Any, List, TypeVar, cast, Callable, Literal, Optional, Protocol
 
 import numpy as np
 import pandas as pd
@@ -7,13 +7,13 @@ import pandas as pd
 if TYPE_CHECKING:
   from ..feature_gen import FeatureGen
   from declafe.feature_gen.Features import Features
-  from declafe.feature_gen.unary import UnaryColumnFeature
+  from declafe.feature_gen.unary import UnaryFeature
   from .. import ColLike
 
 
 class ChainMixin:
 
-  def __init__(self):
+  def __init__(self):  # type: ignore
     from declafe.feature_gen.Features import Features
     self.FS = Features
 
@@ -21,8 +21,7 @@ class ChainMixin:
   def _self(self) -> "FeatureGen":
     raise NotImplementedError
 
-  def next(self, f: Type["UnaryColumnFeature"], *args,
-           **kwargs) -> "FeatureGen":
+  def next(self, f: Type["UnaryFeature"], *args, **kwargs) -> "FeatureGen":
     from declafe.feature_gen.ComposedFeature import ComposedFeature
     from declafe.feature_gen.unary import IdFeature
 
@@ -36,7 +35,10 @@ class ChainMixin:
 
   def of_cond(self, true_col: "ColLike", false_col: "ColLike"):
     from declafe.feature_gen.tri.CondFeature import CondFeature
-    return CondFeature(self._self(), true_col, false_col)
+    from declafe.feature_gen.tri.TriComposeFeature import TriComposeFeature
+
+    return TriComposeFeature.make(  # type: ignore
+        self._self(), true_col, false_col, CondFeature)  # type: ignore
 
   def then(self, func: Callable[[pd.Series], pd.Series],
            op_name: str) -> "FeatureGen":
@@ -75,10 +77,10 @@ class ChainMixin:
     return self.next(AbsFeature)
 
   def is_up(self, period: int = 1) -> "FeatureGen":
-    return (self.pct_change(period) > 0).as_name_of(f"is_up{period}")
+    return ((self._self() - self.lag(1)) > 0).as_name_of(f"is_up{period}")
 
   def is_down(self, period: int = 1) -> "FeatureGen":
-    return (self.pct_change(period) < 0).as_name_of(f"is_down{period}")
+    return ((self._self() - self.lag(1)) < 0).as_name_of(f"is_down{period}")
 
   def moving_averages(self, periods: List[int]) -> "Features":
     return self.FS([self.moving_average(p) for p in periods])
@@ -94,6 +96,22 @@ class ChainMixin:
     from declafe.feature_gen.unary import SumFeature
     return self.next(SumFeature, periods=period)
 
+  class F(Protocol):
+
+    def __call__(self, *args: np.ndarray) -> np.ndarray:
+      ...
+
+  def rolling_apply(
+      self,
+      window: int,
+      func: F,
+      ops_name: str,
+      additional_columns: Optional[List["ColLike"]] = None,
+  ):
+    from declafe.feature_gen.RollingApplyFeature import RollingApplyFeature
+    return RollingApplyFeature(self._self(), window, func, ops_name,
+                               additional_columns)
+
   def ema(self, period: int) -> "FeatureGen":
     from declafe.feature_gen.unary import EMAFeature
     return self.next(EMAFeature, periods=period)
@@ -248,10 +266,18 @@ class ChainMixin:
     from declafe.feature_gen.unary.times import DayOfWeekFeature
     return self.next(DayOfWeekFeature)
 
+  def week_of_year(self) -> "FeatureGen":
+    from declafe.feature_gen.unary.times import WeekOfYearFeature
+    return self.next(WeekOfYearFeature)
+
   def day_of_month(self) -> "FeatureGen":
     from declafe.feature_gen.unary.times import DayOfMonthFeature
     return self.next(DayOfMonthFeature)
 
+  def month(self) -> "FeatureGen":
+    from declafe.feature_gen.unary.times import MonthFeature
+    return self.next(MonthFeature)
+
   def to_datetime(self, unit: Literal["D", "s", "ms", "us",
                                       "ns"]) -> "FeatureGen":
     from declafe.feature_gen.unary.times.ToDatetimeFeature import ToDatetimeFeature
