@@ -1,5 +1,6 @@
 from typing import Any
 
+import numpy as np
 import pandas as pd
 
 from .FeatureGen import FeatureGen
@@ -13,12 +14,15 @@ class ConstFeature(FeatureGen):
     super().__init__()
     self.const = const
 
-  def gen(self, df: pd.DataFrame) -> pd.Series:
-    return pd.Series(self.const, index=df.index)
+  def _gen(self, df: pd.DataFrame) -> np.ndarray:
+    return np.full(len(df), self.const)
 
   def _feature_name(self) -> str:
     return f"{self.const}"
 
+  def extract(self, df: pd.DataFrame) -> pd.Series:
+    return pd.Series(self._gen(df), index=df.index)
+
   @staticmethod
   def conv(a: Any) -> "FeatureGen":
     if not isinstance(a, FeatureGen):
