@@ -1,10 +1,13 @@
 from abc import ABC, abstractmethod
-from typing import TYPE_CHECKING, Optional, Type, Union, Literal, Callable
+from typing import TYPE_CHECKING, Optional, Type, Union, Literal, Callable, Any
 
+import numpy as np
 import pandas as pd
 
 __all__ = ["FeatureGen", "ColLike"]
 
+from numba import jit
+
 from .ChainMixin import ChainMixin
 from .ComplexFeatureMixin import ComplexFeatureMixin
 from .ConstructorMixin import ConstructorMixin
@@ -16,7 +19,6 @@ if TYPE_CHECKING:
   from declafe.feature_gen.Features import Features
 
 ColLike = Union["FeatureGen", str]
-Engine = Literal["cython", "numba"]
 
 
 class FeatureGen(ABC, ConstructorMixin, ChainMixin, OpsMixin,
@@ -29,29 +31,36 @@ class FeatureGen(ABC, ConstructorMixin, ChainMixin, OpsMixin,
     super().__init__()
     self.override_feature_name: Optional[str] = None
     self.dtype: Optional[Union[DTypes, Literal["numeric_auto"]]] = None
-    self.engine: Optional[Engine] = None
+    self._enable_numba = False
 
   @abstractmethod
-  def gen(self, df: pd.DataFrame) -> pd.Series:
-    """
-    generate feature
-    should be side-effect free
-    """
+  def _gen(self, df: pd.DataFrame) -> np.ndarray:
     raise NotImplementedError
 
-  def generate(self, df: pd.DataFrame) -> pd.Series:
+  def __call__(self, df: pd.DataFrame) -> np.ndarray:
+    return self.generate(df)
+
+  def generate(self, df: pd.DataFrame) -> np.ndarray:
     """
     optimized gen
-    side-effect free
     """
+    try:
+      result = df[self.feature_name].to_numpy() \
+        if self.feature_name in df.columns \
+        else self._gen(df)
 
-    result = df[self.feature_name] \
-      if self.feature_name in df.columns \
-      else self.gen(df)
+      dt = infer_min_numeric_type(result) \
+        if self.dtype == "numeric_auto" \
+        else self.dtype
+    except Exception as e:
+      raise Exception(f"Failed to generate {self.feature_name}") from e
 
-    dt = infer_min_numeric_type(result) \
-      if self.dtype == "numeric_auto" \
-      else self.dtype
+    if dt == "category":
+      dt = "int"
+
+    assert len(df) == len(
+        result
+    ), f"len(df)={len(df)}, len(result)={len(result)}, feature_name={self.feature_name}"
 
     return result.astype(dt) if dt else result
 
@@ -67,6 +76,9 @@ class FeatureGen(ABC, ConstructorMixin, ChainMixin, OpsMixin,
     return self.override_feature_name or \
            (self._feature_name())
 
+  def extract(self, df: pd.DataFrame) -> pd.Series:
+    return df[self.feature_name]
+
   def equals(self, other: "FeatureGen") -> bool:
     return self.feature_name == other.feature_name
 
@@ -82,11 +94,18 @@ class FeatureGen(ABC, ConstructorMixin, ChainMixin, OpsMixin,
     return self
 
   def set_feature(self, df: pd.DataFrame) -> "pd.DataFrame":
+    if self.feature_name in df.columns and df[
+        self.feature_name].dtype == self.dtype:
+      return df
+
     temp_df = df.drop(
         columns=[self.feature_name]) if self.feature_name in df.columns else df
 
-    return pd.concat(
-        [temp_df, pd.DataFrame({self.feature_name: self.generate(df)})], axis=1)
+    return pd.concat([
+        temp_df,
+        pd.DataFrame({self.feature_name: self.generate(df)}, index=df.index)
+    ],
+                     axis=1)
 
   def as_type(self, dtype: DTypes) -> "FeatureGen":
     self.dtype = dtype
@@ -107,10 +126,26 @@ class FeatureGen(ABC, ConstructorMixin, ChainMixin, OpsMixin,
   def con_ap(self, f: Callable[["FeatureGen"], "FeatureGen"]) -> "Features":
     return self.to_features.add_feature(f(self))
 
-  def set_engine(self, engine: Engine) -> "FeatureGen":
-    self.engine = engine
+  def enable_numba(self) -> "FeatureGen":
+    self._enable_numba = True
     return self
 
+  def disable_numba(self) -> "FeatureGen":
+    self._enable_numba = False
+    return self
+
+  @property
+  def numba_enabled(self) -> bool:
+    return self._enable_numba
+
+  def numba_dec(self, func: Callable[..., Any]):
+    f = jit(nopython=True)(func) if self.numba_enabled else func
+
+    def wrapper(*args, **kwargs):
+      return f(*args, **kwargs)
+
+    return wrapper
+
   @staticmethod
   def FS() -> "Type[Features]":
     from declafe.feature_gen.Features import Features
@@ -127,5 +162,12 @@ class FeatureGen(ABC, ConstructorMixin, ChainMixin, OpsMixin,
     else:
       return c
 
+  def to_col_feature_gen(self, c: Union["FeatureGen", str]) -> "FeatureGen":
+    if isinstance(c, FeatureGen):
+      return c
+    else:
+      from declafe.feature_gen.unary import IdFeature
+      return IdFeature(c)
+
   def __str__(self):
     return self.feature_name
