@@ -1,15 +1,22 @@
-from dataclasses import dataclass, field
-from typing import List, Type, Callable, Union, TYPE_CHECKING, Literal
 import functools
+from dataclasses import dataclass, field
+from typing import List, Type, Callable, Union, TYPE_CHECKING, TypeVar, Iterable, cast
 
 __all__ = ["Features", "F"]
 
 import pandas as pd
+from tqdm import tqdm
+
+from declafe.feature_gen.types import DTypes
 
 if TYPE_CHECKING:
   from declafe.feature_gen.FeatureGen import FeatureGen
 
-from declafe.feature_gen.unary import UnaryColumnFeature
+from declafe.feature_gen.unary import UnaryFeature
+
+T = TypeVar("T")
+Ap = Callable[[T], "Features"]
+Fun = Callable[[T], "FeatureGen"]
 
 
 @dataclass
@@ -36,15 +43,29 @@ class Features:
     self.feature_gens = fs
     self.pre_processes = ps
 
+  def __call__(self,
+               temp_df: pd.DataFrame,
+               show_progress: bool = False,
+               drop_nan: bool = False):
+    return self.set_features(temp_df, show_progress, drop_nan)
+
   def set_features(self,
                    temp_df: pd.DataFrame,
+                   show_progress: bool = False,
                    drop_nan: bool = False) -> pd.DataFrame:
     df = temp_df
     for p in self.pre_processes:
       df = p.set_feature(df)
 
-    for feature_gen in self.feature_gens:
-      df = feature_gen.set_feature(df)
+    if show_progress:
+      with tqdm(total=self.feature_count) as t:
+        for feature_gen in self.feature_gens:
+          t.set_description(f"Gen: {feature_gen.feature_name}")
+          df = feature_gen.set_feature(df)
+          t.update()
+    else:
+      for feature_gen in self.feature_gens:
+        df = feature_gen.set_feature(df)
 
     if drop_nan:
       df.dropna(inplace=True)
@@ -59,7 +80,7 @@ class Features:
     return [
         f.feature_name
         for f in self.feature_gens
-        if isinstance(f, UnaryColumnFeature) and f.column_name == column_name
+        if isinstance(f, UnaryFeature) and f.column_name == column_name
     ]
 
   def contains(self, feature: "FeatureGen") -> bool:
@@ -92,6 +113,19 @@ class Features:
     return Features(
         [f for f in self.feature_gens if f.feature_name not in feature_names])
 
+  def filter_by_dtype(self, dtypes: Union[DTypes, List[DTypes]]) -> "Features":
+    if isinstance(dtypes, str):
+      dtypes = [dtypes]
+
+    return Features([f for f in self if f.dtype in dtypes])
+
+  def filter_not_by_dtype(self, dtypes: Union[DTypes,
+                                              List[DTypes]]) -> "Features":
+    if isinstance(dtypes, str):
+      dtypes = [dtypes]
+
+    return Features([f for f in self if f.dtype not in dtypes])
+
   def filter(self, feature: List["FeatureGen"]):
     return Features(
         [f for f in self.feature_gens if Features(feature).contains(f)])
@@ -110,11 +144,14 @@ class Features:
              initial: "FeatureGen"):
     return functools.reduce(f, self.feature_gens, initial)
 
-  _F = Union[Type["UnaryColumnFeature"], Callable[["FeatureGen"], "FeatureGen"]]
+  _F = Union[Type["UnaryFeature"], Callable[["FeatureGen"], "FeatureGen"]]
 
   def map(self, f: _F, **kwargs) -> "Features":
-    if isinstance(f, UnaryColumnFeature.__class__):
-      return Features([fg.next(f, **kwargs) for fg in self.feature_gens])
+    if isinstance(f, UnaryFeature.__class__):  # type: ignore
+      return Features([
+          fg.next(cast(Type[UnaryFeature], f), **kwargs)
+          for fg in self.feature_gens
+      ])
     else:
       return Features([f(fg) for fg in self.feature_gens])  # type: ignore
 
@@ -134,8 +171,11 @@ class Features:
   def as_type_auto_num_all(self, override: bool = False):
     return self.map(lambda f: f.as_type_auto_num(override))
 
-  def set_engine(self, engine: Literal["cython", "numba"]):
-    return self.map(lambda f: f.set_engine(engine))
+  def enable_numba(self) -> "Features":
+    return self.map(lambda f: f.enable_numba())
+
+  def disable_numba(self) -> "Features":
+    return self.map(lambda f: f.disable_numba())
 
   @property
   def feature_count(self) -> int:
@@ -160,6 +200,14 @@ class Features:
   def many(*args: "FeatureGen") -> "Features":
     return Features(list(args))
 
+  @staticmethod
+  def iter_over(it: Iterable[T]) -> Ap:
+
+    def ap(f: Fun) -> "Features":
+      return Features([f(x) for x in it])
+
+    return ap
+
   def __iter__(self):
     return self.feature_gens.__iter__()
 
