@@ -1,5 +1,6 @@
 from abc import ABC, abstractmethod
 
+import numpy as np
 import pandas as pd
 
 from ..FeatureGen import FeatureGen, ColLike
@@ -11,10 +12,14 @@ class BinaryFeature(FeatureGen, ABC):
     super().__init__()
     self.left = self.to_col(left)
     self.right = self.to_col(right)
+    self.left_f = self.to_col_feature_gen(left)
+    self.right_f = self.to_col_feature_gen(right)
 
   @abstractmethod
-  def bigen(self, left: pd.Series, right: pd.Series) -> pd.Series:
+  def bigen(self, left: np.ndarray, right: np.ndarray) -> np.ndarray:
     raise NotImplementedError()
 
-  def gen(self, df: pd.DataFrame) -> pd.Series:
-    return self.bigen(df[self.left], df[self.right])
+  def _gen(self, df: pd.DataFrame) -> np.ndarray:
+    return self.bigen(
+        self.left_f.extract(df).to_numpy(),
+        self.right_f.extract(df).to_numpy())
