@@ -1,15 +1,15 @@
-import pandas as pd
-
 __all__ = ["MaxWithFeature"]
 
-from declafe.feature_gen.binary.BinaryFeature import BinaryFeature
 import numpy as np
 
+from declafe.feature_gen.binary.BinaryFeature import BinaryFeature
+from declafe.feature_gen.types import as_numeric
+
 
 class MaxWithFeature(BinaryFeature):
 
-  def bigen(self, left: pd.Series, right: pd.Series) -> pd.Series:
-    return np.maximum(left, right)
+  def bigen(self, left: np.ndarray, right: np.ndarray) -> np.ndarray:
+    return as_numeric(np.maximum(left, right))
 
   def _feature_name(self) -> str:
     return f"{self.left}_max_with_{self.right}"
