@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 
 __all__ = ["AndFeature"]
 
@@ -7,8 +7,8 @@ from ..BinaryFeature import BinaryFeature
 
 class AndFeature(BinaryFeature):
 
-  def bigen(self, left: pd.Series, right: pd.Series) -> pd.Series:
-    return (left & right).astype(bool)
+  def bigen(self, left: np.ndarray, right: np.ndarray) -> np.ndarray:
+    return left.astype(bool) & right.astype(bool)
 
   def _feature_name(self) -> str:
     return f"{self.left}_&_{self.right}"
