@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 
 __all__ = ["EqFeature"]
 
@@ -7,7 +7,7 @@ from ..BinaryFeature import BinaryFeature
 
 class EqFeature(BinaryFeature):
 
-  def bigen(self, left: pd.Series, right: pd.Series) -> pd.Series:
+  def bigen(self, left: np.ndarray, right: np.ndarray) -> np.ndarray:
     return (left == right).astype(bool)
 
   def _feature_name(self) -> str:
