@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
@@ -11,8 +11,8 @@ class AROONDownFeature(BinaryFeature):
     self.period = period
     super().__init__(high, low)
 
-  def bigen(self, left: pd.Series, right: pd.Series) -> pd.Series:
-    return talib.AROON(left, right, self.period)[0]
+  def bigen(self, left: np.ndarray, right: np.ndarray) -> np.ndarray:
+    return talib.AROON(left.astype(float), right.astype(float), self.period)[0]
 
   def _feature_name(self) -> str:
     return f"AROONDown_{self.period}_{self.left}_{self.right}"
@@ -24,8 +24,8 @@ class AROONUpFeature(BinaryFeature):
     self.period = period
     super().__init__(high, low)
 
-  def bigen(self, left: pd.Series, right: pd.Series) -> pd.Series:
-    return talib.AROON(left, right, self.period)[1]
+  def bigen(self, left: np.ndarray, right: np.ndarray) -> np.ndarray:
+    return talib.AROON(left.astype(float), right.astype(float), self.period)[1]
 
   def _feature_name(self) -> str:
     return f"AROONUp_{self.period}_{self.left}_{self.right}"
