@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
@@ -13,8 +13,8 @@ class MIDPRICEFeature(BinaryFeature):
     self.period = period
     super().__init__(high, low)
 
-  def bigen(self, left: pd.Series, right: pd.Series) -> pd.Series:
-    return talib.MIDPRICE(left, right, self.period)
+  def bigen(self, left: np.ndarray, right: np.ndarray) -> np.ndarray:
+    return talib.MIDPRICE(left.astype(float), right.astype(float), self.period)
 
   def _feature_name(self) -> str:
     return f"MIDPRICE_{self.period}_{self.left}_{self.right}"
