@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from ..BinaryFeature import BinaryFeature
@@ -13,8 +13,8 @@ class OBVFeature(BinaryFeature):
   def __init__(self, close: ColLike, volume: ColLike):
     super().__init__(close, volume)
 
-  def bigen(self, left: pd.Series, right: pd.Series) -> pd.Series:
-    return talib.OBV(left, right)
+  def bigen(self, left: np.ndarray, right: np.ndarray) -> np.ndarray:
+    return talib.OBV(left.astype(float), right.astype(float))
 
   def _feature_name(self) -> str:
     return f"OBV_{self.left}_{self.right}"
