@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from ..BinaryFeature import BinaryFeature
@@ -14,8 +14,8 @@ class PlusDMFeature(BinaryFeature):
     super().__init__(high, low)
     self.period = period
 
-  def bigen(self, left: pd.Series, right: pd.Series) -> pd.Series:
-    return talib.PLUS_DM(left, right, self.period)
+  def bigen(self, left: np.ndarray, right: np.ndarray) -> np.ndarray:
+    return talib.PLUS_DM(left.astype(float), right.astype(float), self.period)
 
   def _feature_name(self) -> str:
     return f"PLUS_DM_{self.left}_{self.right}_{self.period}"
