@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
@@ -11,9 +11,10 @@ class ADFeature(QuadriFeature):
                volume: ColLike):
     super().__init__(high, low, close, volume)
 
-  def quadrigen(self, col1: pd.Series, col2: pd.Series, col3: pd.Series,
-                col4: pd.Series) -> pd.Series:
-    return talib.AD(col1, col2, col3, col4)
+  def quadrigen(self, col1: np.ndarray, col2: np.ndarray, col3: np.ndarray,
+                col4: np.ndarray) -> np.ndarray:
+    return talib.AD(col1.astype(float), col2.astype(float), col3.astype(float),
+                    col4.astype(float))
 
   def _feature_name(self) -> str:
     return f"AD_{self.col1}_{self.col2}_{self.col3}_{self.col4}"
