@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
@@ -13,9 +13,10 @@ class CDLBREAKAWAYFeature(QuadriFeature):
                close: ColLike):
     super().__init__(open, high, low, close)
 
-  def quadrigen(self, col1: pd.Series, col2: pd.Series, col3: pd.Series,
-                col4: pd.Series) -> pd.Series:
-    return talib.CDLBREAKAWAY(col1, col2, col3, col4)
+  def quadrigen(self, col1: np.ndarray, col2: np.ndarray, col3: np.ndarray,
+                col4: np.ndarray) -> np.ndarray:
+    return talib.CDLBREAKAWAY(col1.astype(float), col2.astype(float),
+                              col3.astype(float), col4.astype(float))
 
   def _feature_name(self) -> str:
     return f"CDLBREAKAWAY_{self.col1}_{self.col2}_{self.col3}_{self.col4}"
