@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
@@ -18,12 +18,12 @@ class CDLDARKCLOUDCOVERFeature(QuadriFeature):
     super().__init__(open, high, low, close)
     self.penetration = penetration
 
-  def quadrigen(self, col1: pd.Series, col2: pd.Series, col3: pd.Series,
-                col4: pd.Series) -> pd.Series:
-    return talib.CDLDARKCLOUDCOVER(col1,
-                                   col2,
-                                   col3,
-                                   col4,
+  def quadrigen(self, col1: np.ndarray, col2: np.ndarray, col3: np.ndarray,
+                col4: np.ndarray) -> np.ndarray:
+    return talib.CDLDARKCLOUDCOVER(col1.astype(float),
+                                   col2.astype(float),
+                                   col3.astype(float),
+                                   col4.astype(float),
                                    penetration=self.penetration)
 
   def _feature_name(self) -> str:
