@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
@@ -14,9 +14,10 @@ class CCIFeature(TriFeature):
     super().__init__(high, low, close)
     self.period = period
 
-  def trigen(self, col1: pd.Series, col2: pd.Series,
-             col3: pd.Series) -> pd.Series:
-    return talib.CCI(col1, col2, col3, self.period)
+  def trigen(self, col1: np.ndarray, col2: np.ndarray,
+             col3: np.ndarray) -> np.ndarray:
+    return talib.CCI(col1.astype(float), col2.astype(float), col3.astype(float),
+                     self.period)
 
   def _feature_name(self) -> str:
     return f"CCI_{self.period}_of_{self.col1}_{self.col2}_{self.col3}"
