@@ -1,6 +1,6 @@
 from typing import Union
 
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
@@ -19,9 +19,10 @@ class MinusDIFeature(TriFeature):
     super().__init__(high, low, close)
     self.period = period
 
-  def trigen(self, col1: pd.Series, col2: pd.Series,
-             col3: pd.Series) -> pd.Series:
-    return talib.MINUS_DI(col1, col2, col3, self.period)
+  def trigen(self, col1: np.ndarray, col2: np.ndarray,
+             col3: np.ndarray) -> np.ndarray:
+    return talib.MINUS_DI(col1.astype(float), col2.astype(float),
+                          col3.astype(float), self.period)
 
   def _feature_name(self) -> str:
     return f"MINUS_DI_{self.period}_of_{self.col1}_{self.col2}_{self.col3}"
