@@ -1,4 +1,4 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
@@ -12,9 +12,12 @@ class NATRFeature(TriFeature):
     super().__init__(high, low, close)
     self.timeperiod = timeperiod
 
-  def trigen(self, col1: pd.Series, col2: pd.Series,
-             col3: pd.Series) -> pd.Series:
-    return talib.NATR(col1, col2, col3, timeperiod=self.timeperiod)
+  def trigen(self, col1: np.ndarray, col2: np.ndarray,
+             col3: np.ndarray) -> np.ndarray:
+    return talib.NATR(col1.astype(float),
+                      col2.astype(float),
+                      col3.astype(float),
+                      timeperiod=self.timeperiod)
 
   def _feature_name(self) -> str:
     return f"NATR_{self.timeperiod}_of_{self.col1}_{self.col2}_{self.col3}"
