@@ -1,14 +1,13 @@
 import numpy as np
-import pandas as pd
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["AbsFeature"]
 
 
-class AbsFeature(UnaryColumnFeature):
+class AbsFeature(UnaryFeature):
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
     return np.abs(ser)
 
   def _feature_name(self) -> str:
