@@ -1,13 +1,12 @@
 from typing import Callable, Any
 
 import numpy as np
-import pandas as pd
 
 from declafe import ColLike
-from declafe.feature_gen.unary import UnaryColumnFeature
+from declafe.feature_gen.unary import UnaryFeature
 
 
-class AccumulateFeature(UnaryColumnFeature):
+class AccumulateFeature(UnaryFeature):
 
   def __init__(self, column_name: ColLike, ops_name: str,
                ops_func: Callable[[Any, Any], Any]):
@@ -19,5 +18,5 @@ class AccumulateFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"accumulate_{self.ops_name}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
     return np.frompyfunc(self.ops_func, 2, 1).accumulate(ser)
