@@ -1,11 +1,12 @@
+import numpy as np
 import pandas as pd
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["DevisibleFeature"]
 
 
-class DevisibleFeature(UnaryColumnFeature):
+class DevisibleFeature(UnaryFeature):
 
   def __init__(self, deviser: float, column_name: str):
     super().__init__(column_name)
@@ -14,7 +15,7 @@ class DevisibleFeature(UnaryColumnFeature):
     if self.deviser == 0:
       raise ValueError("deviserは0より上である必要があります")
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
     if not pd.api.types.is_numeric_dtype(ser):
       raise ValueError("dTypeは数値型である必要があります")
 
