@@ -1,17 +1,18 @@
+import numpy as np
 import pandas as pd
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["FlipBoolFeature"]
 
 
-class FlipBoolFeature(UnaryColumnFeature):
+class FlipBoolFeature(UnaryFeature):
 
   @property
   def name(self) -> str:
     return f"not"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
     if not pd.api.types.is_bool_dtype(ser):
       raise ValueError("serはbool型である必要があります")
 
