@@ -1,17 +1,16 @@
 from typing import List, TYPE_CHECKING
 
-import pandas as pd
+import numpy as np
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["IdFeature"]
 
 if TYPE_CHECKING:
-  from declafe import FeatureGen
   from declafe.feature_gen.Features import Features
 
 
-class IdFeature(UnaryColumnFeature):
+class IdFeature(UnaryFeature):
 
   @property
   def name(self) -> str:
@@ -20,7 +19,7 @@ class IdFeature(UnaryColumnFeature):
   def _feature_name(self) -> str:
     return self.column_name
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
     return ser
 
   @classmethod
