@@ -1,11 +1,11 @@
-import pandas as pd
+import numpy as np
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["LagFeature"]
 
 
-class LagFeature(UnaryColumnFeature):
+class LagFeature(UnaryFeature):
   """
   ラグ特徴量を追加する
   過去のデータを使用することしか想定していない
@@ -19,5 +19,6 @@ class LagFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"lag_{self.periods}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return ser.shift(self.periods)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return np.where(
+        np.arange(len(ser)) < self.periods, np.nan, np.roll(ser, self.periods))
