@@ -1,14 +1,14 @@
 import numpy as np
 import pandas as pd
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["LogFeature"]
 
 
-class LogFeature(UnaryColumnFeature):
+class LogFeature(UnaryFeature):
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
     if not pd.api.types.is_numeric_dtype(ser):
       raise ValueError("dTypeは数値型である必要があります")
 
