@@ -1,11 +1,11 @@
-import pandas as pd
+import numpy as np
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["MaxCompFeature"]
 
 
-class MaxCompFeature(UnaryColumnFeature):
+class MaxCompFeature(UnaryFeature):
 
   def __init__(self, comp: float, column_name: str):
     super().__init__(column_name)
@@ -15,5 +15,5 @@ class MaxCompFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"max_comp_with_{self.comp}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return ser.apply(lambda x: max(x, self.comp))
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return np.maximum(ser, self.comp)
