@@ -1,11 +1,12 @@
-import pandas as pd
+import numpy as np
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
+import pandas as pd
 
 __all__ = ["MaxFeature"]
 
 
-class MaxFeature(UnaryColumnFeature):
+class MaxFeature(UnaryFeature):
 
   def __init__(self, periods: int, column_name: str):
     super().__init__(column_name)
@@ -18,5 +19,5 @@ class MaxFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"max_{self.periods}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return ser.rolling(self.periods).max(engine=self.engine)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return pd.Series(ser).rolling(self.periods).max().to_numpy()
