@@ -1,11 +1,12 @@
+import numpy as np
 import pandas as pd
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["MedFeature"]
 
 
-class MedFeature(UnaryColumnFeature):
+class MedFeature(UnaryFeature):
 
   def __init__(self, periods: int, column_name: str):
     super().__init__(column_name)
@@ -17,5 +18,5 @@ class MedFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"med_{self.periods}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return ser.rolling(self.periods).median(engine=self.engine)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return pd.Series(ser).rolling(self.periods).median().to_numpy()
