@@ -1,11 +1,11 @@
-import pandas as pd
+import numpy as np
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["MinCompFeature"]
 
 
-class MinCompFeature(UnaryColumnFeature):
+class MinCompFeature(UnaryFeature):
 
   def __init__(self, comp: float, column_name: str):
     super().__init__(column_name)
@@ -15,5 +15,5 @@ class MinCompFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"min_comp_with_{self.comp}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return ser.apply(lambda x: min(x, self.comp))
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return np.minimum(ser, self.comp)
