@@ -1,11 +1,12 @@
+import numpy as np
 import pandas as pd
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["MinFeature"]
 
 
-class MinFeature(UnaryColumnFeature):
+class MinFeature(UnaryFeature):
 
   def __init__(self, periods: int, column_name: str):
     super().__init__(column_name)
@@ -18,5 +19,5 @@ class MinFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"min_{self.periods}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return ser.rolling(self.periods).min(engine=self.engine)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return pd.Series(ser).rolling(self.periods).min().to_numpy()
