@@ -1,11 +1,11 @@
-import pandas as pd
+import numpy as np
 
-from .UnaryColumnFeature import UnaryColumnFeature
+from .UnaryFeature import UnaryFeature
 
 __all__ = ["RoundNFeature"]
 
 
-class RoundNFeature(UnaryColumnFeature):
+class RoundNFeature(UnaryFeature):
 
   def __init__(self, column_name: str, round_digit: int):
     super().__init__(column_name)
@@ -15,5 +15,5 @@ class RoundNFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"round{self.round_digit}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
     return ser.round(self.round_digit)
