@@ -1,20 +1,19 @@
-from .ComposedUnaryFeature import *
 from .ConsecutiveCountFeature import *
-from .DevisibleFeature import DevisibleFeature
-from .FlipBoolFeature import FlipBoolFeature
+from .DevisibleFeature import *
+from .FlipBoolFeature import *
 from .IdFeature import *
-from .LagFeature import LagFeature
+from .LagFeature import *
 from .LogFeature import *
 from .MaxFeature import *
 from .MedFeature import *
 from .MinFeature import *
-from .MovingAverage import MovingAverage
-from .PctChangeFeature import PctChangeFeature
+from .MovingAverage import *
+from .PctChangeFeature import *
 from .PositiveFeature import *
 from .RoundNFeature import *
-from .StddevFeatuer import StddevFeature
+from .StddevFeatuer import *
 from .SumFeature import *
-from .UnaryColumnFeature import *
+from .UnaryFeature import *
 from .talib.APOFeature import *
 from .talib.BBandsFeature import *
 from .talib.EMAFeature import *
@@ -24,5 +23,5 @@ from .talib.MIDEPOINTFeature import *
 from .talib.T3Feature import *
 from .talib.TEMAFeature import *
 from .talib.TRIMAFeature import *
-from .talib.WeightedMovingAverage import WeightedMovingAverage
+from .talib.WeightedMovingAverage import *
 from .talib.DEMAFeature import *
