@@ -1,12 +1,12 @@
-import pandas as pd
+import numpy as np
 import talib
 
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 __all__ = ["APOFeature"]
 
 
-class APOFeature(UnaryColumnFeature):
+class APOFeature(UnaryFeature):
 
   def __init__(self,
                column_name: str,
@@ -22,5 +22,6 @@ class APOFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"APO{self.fastperiod}_{self.slowperiod}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.APO(ser, self.fastperiod, self.slowperiod, self.matype)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.APO(ser.astype("float"), self.fastperiod, self.slowperiod,
+                     self.matype)
