@@ -1,12 +1,12 @@
-import pandas as pd
+import numpy as np
 import talib
 
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 __all__ = ["BBandsUpperFeature", "BBandsLowerFeature"]
 
 
-class BBandsUpperFeature(UnaryColumnFeature):
+class BBandsUpperFeature(UnaryFeature):
 
   def __init__(self,
                periods: int,
@@ -18,15 +18,16 @@ class BBandsUpperFeature(UnaryColumnFeature):
     self.nbdevup = nbdevup
     self.matype = matype
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.BBANDS(ser, self.periods, self.nbdevup, 2, self.matype)[0]
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.BBANDS(ser.astype(float), self.periods, self.nbdevup, 2,
+                        self.matype)[0]
 
   @property
   def name(self) -> str:
     return f"bbands_upper{self.nbdevup}_{self.periods}"
 
 
-class BBandsLowerFeature(UnaryColumnFeature):
+class BBandsLowerFeature(UnaryFeature):
 
   def __init__(self,
                periods: int,
@@ -38,8 +39,9 @@ class BBandsLowerFeature(UnaryColumnFeature):
     self.nbdevdn = nbdevdn
     self.matype = matype
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.BBANDS(ser, self.periods, 2, self.nbdevdn, self.matype)[2]
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.BBANDS(ser.astype(float), self.periods, 2, self.nbdevdn,
+                        self.matype)[2]
 
   @property
   def name(self) -> str:
