@@ -1,12 +1,12 @@
-import pandas as pd
+import numpy as np
 import talib
 
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 __all__ = ["CMOFeature"]
 
 
-class CMOFeature(UnaryColumnFeature):
+class CMOFeature(UnaryFeature):
 
   def __init__(self, periods: int, column_name: str):
     super().__init__(column_name)
@@ -16,5 +16,5 @@ class CMOFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"CMO_{self.periods}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.CMO(ser, self.periods)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.CMO(ser.astype(float), self.periods)
