@@ -1,12 +1,12 @@
-import pandas as pd
+import numpy as np
 import talib
 
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 __all__ = ["DEMAFeature"]
 
 
-class DEMAFeature(UnaryColumnFeature):
+class DEMAFeature(UnaryFeature):
   """double exponential moving average"""
 
   def __init__(self, periods: int, column_name: str):
@@ -17,5 +17,5 @@ class DEMAFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"DEMA_{self.periods}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.DEMA(ser, self.periods)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.DEMA(ser.astype(float), self.periods)
