@@ -1,12 +1,12 @@
-import pandas as pd
+import numpy as np
 import talib
 
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 __all__ = ["EMAFeature"]
 
 
-class EMAFeature(UnaryColumnFeature):
+class EMAFeature(UnaryFeature):
   """exponential moving average"""
 
   def __init__(self, periods: int, column_name: str):
@@ -17,5 +17,5 @@ class EMAFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"EMA_{self.periods}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.EMA(ser, self.periods)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.EMA(ser.astype(float), self.periods)
