@@ -1,12 +1,12 @@
-import pandas as pd
+import numpy as np
 import talib
 
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 __all__ = ["MAMAFeature", "FAMAFeature"]
 
 
-class MAMAFeature(UnaryColumnFeature):
+class MAMAFeature(UnaryFeature):
 
   def __init__(self,
                column_name: str,
@@ -20,11 +20,11 @@ class MAMAFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"mama{self.fast_limit}-{self.slow_limit}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.MAMA(ser, self.fast_limit, self.slow_limit)[0]
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.MAMA(ser.astype(float), self.fast_limit, self.slow_limit)[0]
 
 
-class FAMAFeature(UnaryColumnFeature):
+class FAMAFeature(UnaryFeature):
 
   def __init__(self,
                column_name: str,
@@ -38,5 +38,5 @@ class FAMAFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"fama{self.fast_limit}-{self.slow_limit}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.MAMA(ser, self.fast_limit, self.slow_limit)[1]
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.MAMA(ser.astype(float), self.fast_limit, self.slow_limit)[1]
