@@ -1,12 +1,12 @@
-import pandas as pd
+import numpy as np
 import talib
 
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 __all__ = ["MidpointFeature"]
 
 
-class MidpointFeature(UnaryColumnFeature):
+class MidpointFeature(UnaryFeature):
 
   def __init__(self, periods: int, column_name: str):
     super().__init__(column_name)
@@ -19,5 +19,5 @@ class MidpointFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"midpoint_{self.periods}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.MIDPOINT(ser, self.periods)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.MIDPOINT(ser.astype(float), self.periods)
