@@ -1,12 +1,12 @@
-import pandas as pd
+import numpy as np
 import talib
 
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 __all__ = ["MOMFeature"]
 
 
-class MOMFeature(UnaryColumnFeature):
+class MOMFeature(UnaryFeature):
 
   def __init__(self, period: int, column_name: str):
     super().__init__(column_name)
@@ -16,5 +16,5 @@ class MOMFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"MOM_{self.period}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.MOM(ser, self.period)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.MOM(ser.astype(float), self.period)
