@@ -1,13 +1,13 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 __all__ = ["PPOFeature"]
 
 
-class PPOFeature(UnaryColumnFeature):
+class PPOFeature(UnaryFeature):
 
   def __init__(self,
                column_name: ColLike,
@@ -23,5 +23,6 @@ class PPOFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"PPO_{self.fast_period}_{self.slow_period}_{self.matype}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.PPO(ser, self.fast_period, self.slow_period, self.matype)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.PPO(ser.astype(float), self.fast_period, self.slow_period,
+                     self.matype)
