@@ -1,11 +1,11 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
-from declafe.feature_gen.unary import UnaryColumnFeature
+from declafe.feature_gen.unary import UnaryFeature
 
 
-class RSIFeature(UnaryColumnFeature):
+class RSIFeature(UnaryFeature):
 
   def __init__(self, column_name: ColLike, period: int):
     super().__init__(column_name)
@@ -15,5 +15,5 @@ class RSIFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"RSI_{self.period}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.RSI(ser, timeperiod=self.period)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.RSI(ser.astype(float), timeperiod=self.period)
