@@ -1,11 +1,11 @@
-import pandas as pd
+import numpy as np
 import talib
 
 from declafe import ColLike
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 
-class TRIXFeature(UnaryColumnFeature):
+class TRIXFeature(UnaryFeature):
 
   def __init__(self, column_name: ColLike, period: int):
     super().__init__(column_name)
@@ -15,5 +15,5 @@ class TRIXFeature(UnaryColumnFeature):
   def name(self) -> str:
     return f"TRIX_{self.period}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.TRIX(ser, timeperiod=self.period)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.TRIX(ser.astype(float), timeperiod=self.period)
