@@ -1,10 +1,10 @@
-import pandas as pd
+import numpy as np
 import talib
 
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 
-class WeightedMovingAverage(UnaryColumnFeature):
+class WeightedMovingAverage(UnaryFeature):
   periods: int
 
   def __init__(self, column_name: str, periods: int):
@@ -15,5 +15,5 @@ class WeightedMovingAverage(UnaryColumnFeature):
   def name(self) -> str:
     return f"wma_{self.periods}"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return talib.WMA(ser, self.periods)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return talib.WMA(ser.astype(float), self.periods)
