@@ -1,14 +1,15 @@
 from typing import Literal
 
+import numpy as np
 import pandas as pd
 
 from declafe import ColLike
-from ..UnaryColumnFeature import UnaryColumnFeature
+from ..UnaryFeature import UnaryFeature
 
 Unit = Literal["D", "s", "ms", "us", "ns"]
 
 
-class ToDatetimeFeature(UnaryColumnFeature):
+class ToDatetimeFeature(UnaryFeature):
 
   def __init__(self, column_name: ColLike, unit: Unit):
     super().__init__(column_name)
@@ -18,5 +19,5 @@ class ToDatetimeFeature(UnaryColumnFeature):
   def name(self) -> str:
     return "to_datetime"
 
-  def gen_unary(self, ser: pd.Series) -> pd.Series:
-    return pd.to_datetime(ser, unit=self.unit)
+  def gen_unary(self, ser: np.ndarray) -> np.ndarray:
+    return pd.to_datetime(ser, unit=self.unit).values
